@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #define	TYPE_CMD	0
 #define	TYPE_CONF	1
 
-#define MOD_DIR		"/usr/lib/vzctl/modules/"
+#define MOD_DIR		PKGLIBDIR "/modules/"
 
 #define MOD_INFO_SYM    "vz_get_mod_info"
 
