@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #ifndef _VZERROR_H_
 #define _VZERROR_H_
 
-/***************************** 
+/*****************************
     System errors
 ******************************/
 #define VZ_SETUBC_ERROR			1
@@ -47,7 +47,7 @@
     Argument errors
  ****************************/
 #define VZ_INVALID_PARAMETER_SYNTAX	20
-#define VZ_INVALID_PARAMETER_VALUE	21 
+#define VZ_INVALID_PARAMETER_VALUE	21
 #define VZ_VE_ROOT_NOTSET		22
 #define VZ_VE_PRIVATE_NOTSET		23
 #define VZ_VE_TMPL_NOTSET		24
@@ -55,7 +55,7 @@
 #define VZ_NOTENOUGHUBCPARAMS		28
 #define VZ_VE_PKGSET_NOTSET		29
 /*****************************
-    VE errors
+    CT errors
  *****************************/
 #define VZ_VE_NOT_RUNNING		31
 #define VZ_VE_RUNNING			32
@@ -70,7 +70,7 @@
 /* private area is not mounted */
 #define VZ_FS_NOT_MOUNTED		40
 /* private area is already mounted */
-#define VZ_FS_MOUNTED			41  
+#define VZ_FS_MOUNTED			41
 /* no private area with this id */
 #define VZ_FS_NOPRVT			43
 /* private area with this id already exists */
