@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -83,6 +83,7 @@ struct Cveinfo {
 	int veid;
 	char *hostname;
 	char *name;
+	char *description;
 	char *ip;
 	char *ve_private;
 	char *ve_root;
@@ -94,14 +95,15 @@ struct Cveinfo {
 	int hide;
 };
 
-#define RES_NONE        0
-#define RES_HOSTNAME    1
-#define RES_UBC         2
-#define RES_QUOTA       3
-#define RES_IP          4
-#define RES_LA          5
-#define RES_CPU         6
+#define RES_NONE	0
+#define RES_HOSTNAME	1
+#define RES_UBC		2
+#define RES_QUOTA	3
+#define RES_IP		4
+#define RES_LA		5
+#define RES_CPU		6
 #define RES_NAME	7
+#define RES_DESCRIPTION	8
 
 struct Cfield {
 	char *name;
