@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <linux/vzcalluser.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <limits.h>
 
 #include "logger.h"
 #include "list.h"
@@ -90,6 +91,7 @@ static vps_config config[] = {
 {"NETDEV",	NULL, PARAM_NETDEV_ADD},
 {"",		NULL, PARAM_NETDEV_DEL},
 {"HOSTNAME",	NULL, PARAM_HOSTNAME},
+{"DESCRIPTION",	NULL, PARAM_DESCRIPTION},
 {"NAMESERVER",	NULL, PARAM_NAMESERVER},
 {"IPV6",	NULL, PARAM_IPV6NET},
 {"SEARCHDOMAIN",NULL, PARAM_SEARCHDOMAIN},
@@ -206,16 +208,19 @@ static struct option set_opt[] = {
 /*	netif	*/
 {"netif_add",	required_argument, NULL, PARAM_NETIF_ADD_CMD},
 {"netif_del",	required_argument, NULL, PARAM_NETIF_DEL_CMD},
+{"mac_filter",	required_argument, NULL, PARAM_NETIF_MAC_FILTER},
 
 {"mac",		required_argument, NULL, PARAM_NETIF_MAC},
 {"ifname",	required_argument, NULL, PARAM_NETIF_IFNAME},
 {"host_mac",	required_argument, NULL, PARAM_NETIF_HOST_MAC},
 {"host_ifname",	required_argument, NULL, PARAM_NETIF_HOST_IFNAME},
+{"bridge",	required_argument, NULL, PARAM_NETIF_BRIDGE},
 
 /*	name	*/
 {"name",	required_argument, NULL, PARAM_NAME},
 {"features",	required_argument, NULL, PARAM_FEATURES},
 {"ioprio",	required_argument, NULL, PARAM_IOPRIO},
+{"description",	required_argument, NULL, PARAM_DESCRIPTION},
 
 {NULL, 0, NULL, 0}
 };
@@ -449,7 +454,7 @@ static int parse_iptables(env_param *env, char *val)
 	ret = 0;
 	do {
 		if ((ipt = find_ipt(token)) == NULL) {
-			logger(0, 0, "Warning: Unknown iptable module: %s,"
+			logger(-1, 0, "Warning: Unknown iptable module: %s,"
 				" skipped", token);
 			ret = ERR_INVAL_SKIP;
 			continue;
@@ -1220,6 +1225,9 @@ static int store_misc(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 	case PARAM_NAMESERVER:
 		ret = conf_store_strlist(conf_h, conf->name, &misc->nameserver);
 		break;
+	case PARAM_DESCRIPTION:
+		ret = conf_store_str(conf_h, conf->name, misc->description);
+		break;
 	case PARAM_SEARCHDOMAIN:
 		ret = conf_store_strlist(conf_h, conf->name,
 			&misc->searchdomain);
@@ -1300,7 +1308,7 @@ static int parse_veth_str(const char *str, veth_dev *dev, int operation)
 	memset(dev, 0, sizeof(*dev));
 	if (!operation) {
 		/* Removing veth device */
-		/* Parsing veth device name in VE0 */
+		/* Parsing veth device name in CT0 */
 		if ((ch = strchr(str, ',')) != NULL)
 			return ERR_INVAL;
 		len = strlen(str) + 1;
@@ -1310,7 +1318,7 @@ static int parse_veth_str(const char *str, veth_dev *dev, int operation)
 		return 0;
 	}
 	/* Creating veth device */
-	/* Parsing veth device name in VE0 */
+	/* Parsing veth device name in CT0 */
 	if ((ch = strchr(str, ',')) == NULL)
 		return ERR_INVAL;
 	ch++;
@@ -1320,7 +1328,7 @@ static int parse_veth_str(const char *str, veth_dev *dev, int operation)
 	snprintf(dev->dev_name, len, "%s", str);
 	tmp = ch;
 
-	/* Parsing veth MAC address in VE0 */
+	/* Parsing veth MAC address in CT0 */
 	if ((ch = strchr(tmp, ',')) == NULL)
 		return ERR_INVAL;
 	len = ch - tmp;
@@ -1333,7 +1341,7 @@ static int parse_veth_str(const char *str, veth_dev *dev, int operation)
 	ch++;
 	tmp = ch;
 
-	/* Parsing veth name in VE */
+	/* Parsing veth name in CT */
 	if ((ch = strchr(tmp, ',')) == NULL)
 		return ERR_INVAL;
 	ch++;
@@ -1342,7 +1350,7 @@ static int parse_veth_str(const char *str, veth_dev *dev, int operation)
 		return ERR_INVAL;
 	snprintf(dev->dev_name_ve, len, "%s", tmp);
 
-	/* Parsing veth MAC address in VE */
+	/* Parsing veth MAC address in CT */
 	len = strlen(ch);
 	if (len != 3*ETH_ALEN -1)
 		return ERR_INVAL;
@@ -1376,6 +1384,22 @@ static int parse_veth(vps_param *vps_p, char *val, int operation)
 }
 
 /********************* NETIF **********************************/
+
+static int parse_mac_filter_cmd (veth_dev *dev, char *str)
+{
+
+	if (dev == NULL)
+		return ERR_INVAL;
+
+	if (!strcmp(str, "on"))
+		dev->mac_filter = YES;
+	else if (!strcmp(str, "off"))
+		dev->mac_filter = NO;
+	else
+		return ERR_INVAL;
+	return 0;
+}
+
 void generate_veth_name(int veid, char *dev_name_ve,  char *dev_name, int len)
 {
 	char *name;
@@ -1391,6 +1415,7 @@ static int add_netif_param(veth_param *veth, int opt, char *str)
 {
 	veth_dev *dev;
 	int len;
+	int ret;
 
 	dev = NULL;
 	dev = find_veth_configure(&veth->dev);
@@ -1426,6 +1451,20 @@ static int add_netif_param(veth_param *veth, int opt, char *str)
 			return ERR_INVAL;
 		dev->addrlen = ETH_ALEN;
 		break;
+	case PARAM_NETIF_MAC_FILTER:
+		if ((ret = parse_mac_filter_cmd(dev, str)))
+			return ret;
+		break;
+	case PARAM_NETIF_BRIDGE:
+		if (dev->dev_bridge[0] != 0) {
+			logger(-1, 0,"Multiple use of"
+				" --bridge option not allowed");
+			return ERR_INVAL;
+		}
+		if (len > IFNAMSIZE)
+			return ERR_INVAL;
+		strcpy(dev->dev_bridge, str);
+		break;
 	}
 	return 0;
 }
@@ -1477,6 +1516,25 @@ static int parse_netif_str(envid_t veid, const char *str, veth_dev *dev)
 			if (err)
 				return err;
 			dev->addrlen = ETH_ALEN;
+		} else if (!strncmp("mac_filter=", p, 11)) {
+			p += 11;
+			len = next - p;
+			if (len == 0)
+				continue;
+			if (len >= sizeof(tmp))
+				return ERR_INVAL;
+			strncpy(tmp, p, len);
+			tmp[len] = 0;
+			err = parse_mac_filter_cmd(dev, tmp);
+			if (err)
+				return err;
+		} else if (!strncmp("bridge=", p, 7)) {
+			p += 7;
+			len = next - p;
+			if (len > IFNAMSIZE)
+				return ERR_INVAL;
+			if (dev->dev_bridge[0] == '\0')
+				strncpy(dev->dev_bridge, p, len);
 		}
 		p = ++next;
 	} while (p < ep);
@@ -1574,6 +1632,12 @@ static int store_netif(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 			if (sp >= ep)
 				break;
 		}
+		if (dev->dev_bridge[0] != 0) {
+			sp += snprintf(sp, ep - sp, "bridge=%s,",
+				dev->dev_bridge);
+			if (sp >= ep)
+				break;
+		}
 		if (dev->addrlen_ve != 0) {
 			sp += snprintf(sp, ep - sp,
 				"mac=%02X:%02X:%02X:%02X:%02X:%02X,",
@@ -1594,6 +1658,12 @@ static int store_netif(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 			if (sp >= ep)
 				break;
 		}
+		if (dev->mac_filter) {
+			sp += snprintf(sp, ep - sp, "mac_filter=%s,",
+				dev->mac_filter == YES ? "on" : "off");
+			if (sp >= ep)
+				break;
+		}
 		if (prev != sp)
 			*(sp-1) = 0;
 		if (sp >= ep)
@@ -1614,7 +1684,7 @@ static int parse_netif_str_cmd(envid_t veid, const char *str, veth_dev *dev)
 	memset(dev, 0, sizeof(*dev));
 	ep = str + strlen(str);
 	/* Creating veth device */
-	/* Parsing veth device name in VE */
+	/* Parsing veth device name in CT */
 	if ((ch = strchr(str, ',')) == NULL) {
 		ch = ep;
 		len = ep - str;
@@ -1635,7 +1705,7 @@ static int parse_netif_str_cmd(envid_t veid, const char *str, veth_dev *dev)
 		dev->addrlen = ETH_ALEN;
 		return 0;
 	}
-	/* Parsing veth MAC address in VE */
+	/* Parsing veth MAC address in CT */
 	if ((ch = strchr(tmp, ',')) == NULL) {
 		ch = ep;
 		len = ch - tmp;
@@ -1643,17 +1713,24 @@ static int parse_netif_str_cmd(envid_t veid, const char *str, veth_dev *dev)
 		len = ch - tmp;
 		ch++;
 	}
-	if (len != MAC_SIZE) {
-		logger(-1, 0, "Invalid VE MAC address length");
-		return ERR_INVAL;
+	
+	if (len) {
+	        if (len != MAC_SIZE) {
+		        logger(-1, 0, "Invalid container MAC address length");
+			return ERR_INVAL;
+		}
+		err = parse_hwaddr(tmp, dev->dev_addr_ve);
+		if (err) {
+		  logger(-1, 0, "Invalid container MAC address format");
+		  return ERR_INVAL;
+		}
+	} else {
+		generate_mac(veid, dev->dev_name_ve, dev->dev_addr_ve);
 	}
-	err = parse_hwaddr(tmp, dev->dev_addr_ve);
-	if (err) {
-		logger(-1, 0, "Invalid VE MAC address format");
-		return ERR_INVAL;
-	}
-	dev->addrlen = ETH_ALEN;
+	dev->addrlen_ve = ETH_ALEN;
+
 	tmp = ch;
+
 	if (ch == ep) {
 		generate_veth_name(veid, dev->dev_name_ve, dev->dev_name,
 			sizeof(dev->dev_name));
@@ -1661,7 +1738,7 @@ static int parse_netif_str_cmd(envid_t veid, const char *str, veth_dev *dev)
 		dev->addrlen = ETH_ALEN;
 		return 0;
 	}
-	/* Parsing veth name in VE0 */
+	/* Parsing veth name in CT0 */
 	if ((ch = strchr(tmp, ',')) == NULL) {
 		ch = ep;
 		len = ch - tmp;
@@ -1669,26 +1746,58 @@ static int parse_netif_str_cmd(envid_t veid, const char *str, veth_dev *dev)
 		len = ch - tmp;
 		ch++;
 	}
-	if (len > IFNAMSIZE)
-		return ERR_INVAL;
-	snprintf(dev->dev_name, len + 1, "%s", tmp);
-	if (ch == ep) {
-		memcpy(dev->dev_addr, dev->dev_addr_ve, ETH_ALEN);
+	if (len) {
+	        if (len > IFNAMSIZE)
+		        return ERR_INVAL;
+		snprintf(dev->dev_name, len + 1, "%s", tmp);
+		if (ch == ep) {
+		        memcpy(dev->dev_addr, dev->dev_addr_ve, ETH_ALEN);
+			dev->addrlen = ETH_ALEN;
+			return 0;
+		}
+	} else {
+	        generate_veth_name(veid, dev->dev_name_ve, dev->dev_name,
+				   sizeof(dev->dev_name));
+	}
+
+	tmp = ch;
+
+	/* Parsing veth MAC address in CT */
+	if ((ch = strchr(tmp, ',')) == NULL) {
+		ch = ep;
+		len = ch - tmp;
+	} else {
+		len = ch - tmp;
+		ch++;
+	}
+
+	if (len) {
+	        if (len != MAC_SIZE) {
+		        logger(-1, 0, "Invalid host MAC address");
+			return ERR_INVAL;
+		}
+		err = parse_hwaddr(tmp, dev->dev_addr);
+		if (err) {
+		  logger(-1, 0, "Invalid host MAC address");
+		  return ERR_INVAL;
+		}
 		dev->addrlen = ETH_ALEN;
-		return 0;
+		if (ch == ep) {
+		        return 0;
+		}
+	} else {
+	        generate_mac(veid, dev->dev_name, dev->dev_addr);
+	        dev->addrlen = ETH_ALEN;
 	}
-	/* Parsing veth MAC address in VE */
-	len = strlen(ch);
-	if (len != MAC_SIZE) {
-		logger(-1, 0, "Invalid host MAC address");
-		return ERR_INVAL;
-	}
-	err = parse_hwaddr(ch, dev->dev_addr);
-	if (err) {
-		logger(-1, 0, "Invalid host MAC address");
-		return ERR_INVAL;
-	}
-	dev->addrlen_ve = ETH_ALEN;
+
+	/* Parsing bridge name */
+	len = strlen (ch);
+
+	if (len > IFNAMSIZE)
+	        return ERR_INVAL;
+
+	snprintf(dev->dev_bridge, len + 1, "%s", ch);
+
 	return 0;
 }
 
@@ -1764,6 +1873,9 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_HOSTNAME:
 		ret = conf_parse_str(&vps_p->res.misc.hostname, val, 1);
 		break;
+	case PARAM_DESCRIPTION:
+		ret = conf_parse_str(&vps_p->res.misc.description, val, 1);
+		break;
 	case PARAM_NAMESERVER:
 		ret = conf_parse_strlist(&vps_p->res.misc.nameserver, val, 1);
 		break;
@@ -2021,6 +2133,8 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_NETIF_MAC:
 	case PARAM_NETIF_HOST_IFNAME:
 	case PARAM_NETIF_HOST_MAC:
+	case PARAM_NETIF_MAC_FILTER:
+	case PARAM_NETIF_BRIDGE:
 		ret = add_netif_param(&vps_p->res.veth, id, val);
 		break;
 	case PARAM_NAME:
@@ -2075,7 +2189,7 @@ static int store(vps_param *old_p, vps_param *vps_p, list_head_t *conf_h)
 }
 
 /********************************************************/
-/*	VE parse config stuff				*/
+/*	CT parse config stuff				*/
 /********************************************************/
 
 int vps_parse_config(envid_t veid, char *path, vps_param *vps_p,
@@ -2145,7 +2259,7 @@ int vps_parse_config(envid_t veid, char *path, vps_param *vps_p,
 }
 
 /********************************************************/
-/*	VE save config stuff				*/
+/*	CT save config stuff				*/
 /********************************************************/
 static int read_conf(char *fname, list_head_t *conf_h)
 {
@@ -2383,7 +2497,7 @@ int set_name(int veid, char *new_name, char *old_name)
 	}
 	veid_old = get_veid_by_name(new_name);
 	if (veid_old >= 0 && veid_old != veid) {
-		logger(-1, 0, "Conflict: name %s already used by VE %d",
+		logger(-1, 0, "Conflict: name %s already used by container %d",
 			new_name, veid_old);
 		return VZ_SET_NAME_ERROR;
 	}
@@ -2459,6 +2573,7 @@ static void free_misc(misc_param *misc)
 	free_str_param(&misc->searchdomain);
 	free_str_param(&misc->userpw);
 	FREE_P(misc->hostname)
+	FREE_P(misc->description)
 }
 
 static void free_net(net_param *net)
@@ -2536,6 +2651,8 @@ void free_vps_param(vps_param *param)
 
 #define MERGE_INT(x)	if (src->x) dst->x = src->x;
 
+#define MERGE_INT2(x)	if (src->x >= 0) dst->x = src->x;
+
 #define MERGE_P(x)							\
 	if ((src->x) != NULL) { 					\
 		if ((dst->x) == NULL) 					\
@@ -2615,6 +2732,7 @@ static void merge_misc(misc_param *dst, misc_param *src)
 	MERGE_LIST(searchdomain)
 	MERGE_LIST(userpw)
 	MERGE_STR(hostname)
+	MERGE_STR(description)
 	MERGE_INT(wait);
 }
 
@@ -2665,7 +2783,7 @@ static void merge_cpt(cpt_param *dst, cpt_param *src)
 
 static void merge_meminfo(meminfo_param *dst, meminfo_param *src)
 {
-	MERGE_INT(mode);
+	MERGE_INT2(mode);
 	MERGE_INT(val);
 }
 
@@ -2684,7 +2802,7 @@ static void merge_name(name_param *dst, name_param *src)
 }
 
 static void merge_io(io_param *dst, io_param *src) {
-	MERGE_INT(ioprio);
+	MERGE_INT2(ioprio);
 }
 
 static int merge_res(vps_res *dst, vps_res *src)
