@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #include "vps_configure.h"
 #include "io.h"
 
-/** Function called on VE start to setup resource management
+/** Function called on CT start to setup resource management
  *
  */
 int setup_resource_management(vps_handler *h, envid_t veid, vps_res *res)
@@ -51,7 +51,7 @@ int setup_resource_management(vps_handler *h, envid_t veid, vps_res *res)
 	return 0;
 }
 
-/** Function called on VE stop to cleanup resources
+/** Function called on CT stop to cleanup resources
  *
  */
 int vps_cleanup_res(vps_handler *h, envid_t veid, vps_param *param, int vps_state)
@@ -69,7 +69,7 @@ int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 {
 	int ret;
 	vps_res *res = &param->res;
-	
+
 	if (skip & SKIP_SETUP)
 		return 0;
 	if (vps_state != STATE_STARTING) {
@@ -86,9 +86,8 @@ int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 	{
 		return ret;
 	}
-	if ((ret = vps_netdev_ctl(h, veid, DEL, &param->del_res.net)))
-		return ret;
-	if ((ret = vps_netdev_ctl(h, veid, ADD, &res->net)))
+	if ((ret = vps_set_netdev(h, veid, &res->ub,
+					&res->net, &param->del_res.net)))
 		return ret;
 	if ((ret = vps_set_cpu(h, veid, &res->cpu)))
 		return ret;
@@ -96,21 +95,23 @@ int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 		return ret;
 	if ((ret = vps_set_fs(fs, &res->fs)))
 		return ret;
-	if((ret = vps_meminfo_set(h, veid, &res->meminfo, param)))
+	if((ret = vps_meminfo_set(h, veid, &res->meminfo, param, vps_state)))
 		return ret;
 	if ((ret = ve_ioprio_set(h, veid, &res->io, param)))
 		return ret;
 
 	if (vps_state == STATE_RUNNING && vps_is_run(h, veid)) {
 		if (res->cap.on || res->cap.off)
-			logger(-1, 0, "Unable to set capability on running VE");
+			logger(-1, 0, "Unable to set capability "
+					"on running container");
 		if (res->env.ipt_mask) {
-			logger(-1, 0, "Unable to set iptables on running VE");
+			logger(-1, 0, "Unable to set iptables "
+					"on running container");
 			return VZ_SET_IPTABLES;
 		}
 	}
 	if (!(skip & SKIP_CONFIGURE))
-		vps_configure(h, veid, actions, fs->root, ADD, res, vps_state);
+		vps_configure(h, veid, actions, fs->root, ADD, param, vps_state);
 	/* Setup quota limits after configure steps */
 	if ((ret = vps_set_quota(veid, &res->dq)))
 		return ret;
