@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <fcntl.h>
 #include <arpa/inet.h>
 #include <stdarg.h>
-#include <linux/limits.h>
+#include <limits.h>
 #include <dirent.h>
 
 #include "util.h"
