@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,8 +32,6 @@
 #include "util.h"
 #include "modules.h"
 
-LOG_DATA
-
 struct mod_action g_action;
 char *_proc_title;
 int _proc_title_len;
@@ -45,21 +43,22 @@ int parse_action_opt(envid_t veid, int action, int argc, char *argv[],
 int run_action(envid_t veid, int action, vps_param *g_p, vps_param *vps_p,
 	vps_param *cmd_p, int argc, char **argv, int skiplock);
 
-void version()
+void version(FILE *fp)
 {
-	fprintf(stdout, "vzctl version " VERSION "\n");
+	fprintf(fp, "vzctl version " VERSION "\n");
 }
 
-void usage()
+void usage(int rc)
 {
 	struct mod_action mod;
+	FILE *fp = rc ? stderr : stdout;
 
-	version();
-	fprintf(stdout, "Copyright (C) 2000-2007 SWsoft.\n");
-	fprintf(stdout, "This program may be distributed under the terms of the GNU GPL License.\n\n");
-	fprintf(stdout, "Usage: vzctl [options] <command> <veid> [parameters]\n"
-"vzctl destroy | mount | umount | stop | status | enter <veid>\n"
-"vzctl create <veid> {--ostemplate <name>] [--config <name>]\n"
+	version(fp);
+	fprintf(fp, "Copyright (C) 2000-2008, Parallels, Inc.\n");
+	fprintf(fp, "This program may be distributed under the terms of the GNU GPL License.\n\n");
+	fprintf(fp, "Usage: vzctl [options] <command> <veid> [parameters]\n"
+"vzctl destroy | mount | umount | stop | restart | status | enter <veid>\n"
+"vzctl create <veid> [--ostemplate <name>] [--config <name>]\n"
 "   [--private <path>] [--root <path>] [--ipadd <addr>] | [--hostname <name>]\n"
 "vzctl start <veid> [--force] [--wait]\n"
 "vzctl exec | exec2 <veid> <command> [arg ...]\n"
@@ -75,14 +74,14 @@ void usage()
 "   [--noatime yes|no] [--capability <name>:on|off ...]\n"
 "   [--devices b|c:major:minor|all:r|w|rw]\n"
 "   [--devnodes device:r|w|rw|none]\n"
-"   [--netif_add <ifname[,mac,host_ifname,host_mac]]>] [--netif_del <ifname>]\n"
+"   [--netif_add <ifname[,mac,host_ifname,host_mac,bridge]]>] [--netif_del <ifname>]\n"
 "   [--applyconfig <name>] [--applyconfig_map <name>]\n"
 "   [--features <name:on|off>] [--name <vename>]\n"
 "   [--ioprio <N>]\n");
 
 
-	fprintf(stdout, "   [--iptables <name>] [--disabled <yes|no>]\n");
-	fprintf(stdout, "   [UBC parameters]\n"
+	fprintf(fp, "   [--iptables <name>] [--disabled <yes|no>]\n");
+	fprintf(fp, "   [UBC parameters]\n"
 "UBC parameters (N - items, P - pages, B - bytes):\n"
 "Two numbers divided by colon means barrier:limit.\n"
 "In case the limit is not given it is set to the same value as the barrier.\n"
@@ -98,6 +97,7 @@ void usage()
 	init_modules(&mod, NULL);
 	mod_print_usage(&mod);
 	free_modules(&mod);
+	exit(rc);
 }
 
 int main(int argc, char *argv[], char *envp[])
@@ -150,7 +150,7 @@ int main(int argc, char *argv[], char *envp[])
 		} else if (!strcmp(opt, "--quiet"))
 			quiet = 1;
 		else if (!strcmp(opt, "--version")) {
-			version();
+			version(stdout);
 			exit(0);
 		} else if (!strcmp(opt, "--skiplock"))
 			skiplock = YES;
@@ -158,10 +158,8 @@ int main(int argc, char *argv[], char *envp[])
 			break;
 		argc--; argv++;
 	}
-	if (argc <= 1)	{
-		usage();
-		exit(VZ_INVALID_PARAMETER_SYNTAX);
-	}
+	if (argc <= 1)
+		usage(VZ_INVALID_PARAMETER_SYNTAX);
 	action_nm = argv[1];
 	init_log(NULL, 0, 1, verbose, 0, NULL);
 	if (!strcmp(argv[1], "set")) {
@@ -216,8 +214,7 @@ int main(int argc, char *argv[], char *envp[])
 	} else if (!strcmp(argv[1], "quotainit")) {
 		action = ACTION_QUOTAINIT;
 	} else if (!strcmp(argv[1], "--help")) {
-		usage();
-		exit(0);
+		usage(0);
 	} else {
 		init_modules(&g_action, action_nm);
 		action = ACTION_CUSTOM;
@@ -228,7 +225,7 @@ int main(int argc, char *argv[], char *envp[])
 		}
 	}
 	if (argc < 3) {
-		fprintf(stderr, "VE id is not given\n");
+		fprintf(stderr, "CT ID missing\n");
 		ret = VZ_INVALID_PARAMETER_VALUE;
 		goto error;
 	}
@@ -236,7 +233,7 @@ int main(int argc, char *argv[], char *envp[])
 		name = strdup(argv[2]);
 		veid = get_veid_by_name(name);
 		if (veid < 0) {
-			fprintf(stderr, "Bad VE id %s\n", argv[2]);
+			fprintf(stderr, "Bad CT ID %s\n", argv[2]);
 			ret = VZ_INVALID_PARAMETER_VALUE;
 			goto error;
 		}
@@ -252,7 +249,7 @@ int main(int argc, char *argv[], char *envp[])
 	init_log(gparam->log.log_file, veid, gparam->log.enable != NO,
 		gparam->log.level, quiet, "vzctl");
 	/* Set verbose level from global config if not overwriten
-	   by --verbose 
+	   by --verbose
 	*/
 	if (!verbose_custom && gparam->log.verbose != NULL) {
 		verbose = *gparam->log.verbose;
@@ -268,11 +265,11 @@ int main(int argc, char *argv[], char *envp[])
 		goto error;
 	}
 	if (veid == 0 && action != ACTION_SET) {
-		fprintf(stderr, "Only set actions allowed for VE0");
+		fprintf(stderr, "Only set actions are allowed for CT0\n");
 		ret = VZ_INVALID_PARAMETER_VALUE;
 		goto error;
 	} else if (veid < 0) {
-		fprintf(stderr, "Bad VE id %d\n", veid);
+		fprintf(stderr, "Bad CT ID %d\n", veid);
 		ret = VZ_INVALID_PARAMETER_VALUE;
 		goto error;
 	}
@@ -288,7 +285,8 @@ int main(int argc, char *argv[], char *envp[])
 		    vps_p->res.name.name != NULL &&
 		    strcmp(name, vps_p->res.name.name))
 		{
-			logger(-1, 0, "Unable to find VE by name %s", name);
+			logger(-1, 0, "Unable to find container by name %s",
+					name);
 			ret = VZ_INVALID_PARAMETER_VALUE;
 			goto error;
 		}
@@ -296,7 +294,7 @@ int main(int argc, char *argv[], char *envp[])
 			action != ACTION_STATUS &&
 			action != ACTION_SET)
 	{
-		logger(-1, 0, "VE config file does not exist");
+		logger(-1, 0, "Container config file does not exist");
 		ret = VZ_NOVECONFIG;
 		goto error;
 	}
